diff --git a/Vue/gabarit.php b/Vue/gabarit.php
index afd334b..9fb6c47 100755
--- a/Vue/gabarit.php
+++ b/Vue/gabarit.php
@@ -885,7 +885,7 @@
-
+
diff --git a/Js/fonctions.js b/Js/fonctions.js
index 6ecf478..49fdf39 100755
--- a/Js/fonctions.js
+++ b/Js/fonctions.js
@@ -5357,7 +5357,17 @@ async function facturer_feuillemaladie() {
return;
}
- // Vérification si le prix est nul
+ const otpStatus = $("#otpStatus").val();
+ // Gestion OTP facturation
+ alert("otpStatus => "+otpStatus);
+ if (otpStatus!=1 && otpStatus!=-1) {
+ const v_msg = "Déjà facturé!";
+ const v_msgEng = "Already charged!";
+ alert_ebene(v_msg, v_msgEng);
+ return;
+ }
+
+ // Vérification si le prix est nul
if (prixActe === "0") {
const v_msg = "Rien à facturer!";
const v_msgEng = "Nothing to charge!";